
/***

Program Code: Street Prostitution Zones and Crime (Bischop, Kastoryano,van der Klaauw)
Author: Stephen Kastoryano
Date: this version: 28.01.2016
STATA version: 14.1

Note: Standard errors from the cgmwildboot command may vary slightly depending 
	  on the seed and STATA version.
	  
	  
Original Data:
 Registered Crime: 
   These data are publicly available at Statline CBS Netherlands, http://statline.cbs.nl/Statweb/
   For crime outcomes follow: 
	 Zoeken op thema -> Nederland Regionaal -> Per Thema -> Veiligheid en recht -> 
      Misdrijven; ingeschreven strafzaken grote gemeenten (indeling 2011) '94-'11
 Perceived Crime: 
   These data are not publicly available. Information on accessing these data is
   available at:
	 http://www.scp.nl/Onderzoek/Bronnen/Beknopte_onderzoeksbeschrijvingen/Politiemonitor_bevolking_PMB
	 http://www.scp.nl/Onderzoek/Bronnen/Beknopte_onderzoeksbeschrijvingen/Veiligheidsmonitor_Rijk_VMR
 
***/



/*************************************************************************/
/*** Table 2: Summary statistics on registered crime   *******************/
/*************************************************************************/

/*** column 1 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\CBSregist2015.dta", clear 
local controls "popul_100 popmale1565_100 pop_dens_100  inkhh educhpc nondutchpc  insurWWAO_pc  mayorSoc mayorLib mayorChr"
keep if city=="Amsterdam" | city=="Rotterdam" | city=="Den Haag"
tabstat rapesexapcN sexassaultpcN rapepcN drugspcN maltreatpcN weaponspcN, s(mean sd) f(%5.2f)
tabstat `controls', s(mean sd) f(%5.2f)

/*** column 2 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\CBSregist2015.dta", clear 
local controls "popul_100 popmale1565_100 pop_dens_100  inkhh educhpc nondutchpc  insurWWAO_pc  mayorSoc mayorLib mayorChr"
keep if city=="Utrecht" | city=="Nijmegen" | city=="Groningen" | city=="Heerlen" | city=="Eindhoven" | city=="Arnhem"
tabstat rapesexapcN sexassaultpcN rapepcN drugspcN maltreatpcN weaponspcN, s(mean sd) f(%5.2f)
tabstat `controls', s(mean sd) f(%5.2f)

/*** column 3 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\CBSregist2015.dta", clear 
local controls "popul_100 popmale1565_100 pop_dens_100  inkhh educhpc nondutchpc  insurWWAO_pc  mayorSoc mayorLib mayorChr"
drop if city=="Amsterdam" | city=="Rotterdam" | city=="Utrecht" | city=="Den Haag" | city=="Nijmegen" | city=="Groningen" | city=="Heerlen" | city=="Eindhoven" | city=="Arnhem"
tabstat rapesexapcN sexassaultpcN rapepcN drugspcN maltreatpcN weaponspcN, s(mean sd) f(%5.2f)
tabstat `controls', s(mean sd) f(%5.2f)



/*************************************************************************************/
/*** Tables 3-6 + Appendix 12-14: Registered Crime Analysis        *******************/
/*************************************************************************************/

use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\CBSregist2015.dta", clear 




/******************************/
/*** Registered 25 cities   ***/
/******************************/   

tabulate city, generate(dc)
tabulate year, generate(dy)


/*** Table 3, 25 cities ***/
/**************************/

local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "opening"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear

local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "everopenNoReg openingRegP openingRegA  closing"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Table 5, 25 cities ***/
/**************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "opening"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "everopenNoReg openingRegP openingRegA closing"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear




/*** Appendix: Table 12, 25 cities ***/
/*************************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
tsset city1 year, yearly
xtset city1 year 
local effects "everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnrapesexaN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnsexassaultN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnrapeN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Appendix: Table 13, 25 cities ***/
/*************************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
tsset city1 year, yearly
xtset city1 year 
local effects "everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lndrugsN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnweaponsN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects " everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnmaltreatN  `effects'  dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg openingRegP openingRegA closing"
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc25 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear




/******************************/
/*** Registered 22 cities   ***/
/******************************/

use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\CBSregist2015.dta", clear 

drop if city=="Amsterdam"
drop if city=="Rotterdam"
drop if city=="Den Haag"
drop if city=="Eindhoven" & year==2011

tabulate city, generate(dc)
tabulate year, generate(dy)


/*** Table 3: 22 cities ***/
/***************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "opening"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear

local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "everopenNoReg  openingRegP openingRegA"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear 


/*** Table 4 ***/
/***************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
tsset city1 year, yearly
xtset city1 year 
local effects "openingNoReg12 everopenNoReg38p openingRegP openingReg12 openingReg38pA "
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
local effects " opening12m openingNoReg12 everopenNoReg38p  openingRegP12m openingRegP openingReg12 openingReg38pA "
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
local effects " openingNoReg12 everopenNoReg38p  openingRegP openingReg12 openingReg38pA regspillNoReg closespillNoReg "
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
local effects "openingNoReg12 everopenNoReg38p  openingRegP openingReg12 openingReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
local effects "openingNoReg12 everopenNoReg38p  openingRegP openingReg12 openingReg38pA  regspillNoReg closespillNoReg brothelban openspillRegA openspillNoReg openspillRegP "
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
test _b[openingNoReg12]+_b[everopenNoReg38p]=_b[openingReg12]+_b[openingReg38pA]
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
test _b[openingNoReg12]=_b[openingReg12]
test _b[everopenNoReg38p]=_b[openingReg38pA]
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects' opening12m openingRegP12m)
eststo clear



/*** Table 5: 22 cities ***/
/**************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "opening"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear

local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "everopenNoReg openingRegP openingRegA"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear 

/*** Appendix: Fals. 22 cities ***/
/*********************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "opening"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lntheftN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnpordoffN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnpordviolN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear

local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "everopenNoReg openingRegP openingRegA"
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lntheftN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnpordoffN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnpordviolN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Appendix: Table 12, 22 cities ***/
/*************************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
tsset city1 year, yearly
xtset city1 year 
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnrapesexaN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnsexassaultN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnrapeN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Appendix: Table 13, 22 cities ***/
/*************************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
tsset city1 year, yearly
xtset city1 year 
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lndrugsN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnweaponsN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnmaltreatN  `effects'  dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
local effects "opening12m everopenNoReg  openingRegP openingRegA "
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Appendix Table 14   ***/
/***************************/
local controls "logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorCU mayorD66 mayorVVD"
local effects "openingNoReg12 everopenNoReg38p  openingRegP openingReg12 openingReg38pA regspillNoReg closespillNoReg brothelban openspillRegA openspillNoReg openspillRegP "
tsset city1 year, yearly
xtset city1 year 
eststo: qui cgmwildboot lnrapesexaN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnsexassaultN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnrapeN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lndrugsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnweaponsN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
eststo: qui cgmwildboot lnmaltreatN  `effects' `controls' dc2-dc22 dy2-dy18, cluster(city1) bootcluster(city1) reps(499) seed(45571)
esttab, se  b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear




/*************************************************************************************/
/*** Tables 8-9 + Appendix 15: Perceived Crime Analysis            *******************/
/*************************************************************************************/


/*************************************************************************/
/*** Table 6: Summary statistics on perceived crime   *******************/
/*************************************************************************/

/*** column 1 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\PMBperc2015.dta", clear 
keep if city=="Amsterdam" | city=="Rotterdam" | city=="Den Haag"
tabstat drugs1 drugs2  drugs3  violence1  violence2 violence3  , s(mean sd) f(%5.2f)

/*** column 2 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\PMBperc2015.dta", clear 
keep if city=="Utrecht" | city=="Nijmegen" | city=="Groningen" | city=="Heerlen" | city=="Eindhoven" | city=="Arnhem"
tabstat drugs1 drugs2  drugs3  violence1  violence2 violence3  , s(mean sd) f(%5.2f)

/*** column 3 ***/
use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\PMBperc2015.dta", clear 
drop if city=="Amsterdam" | city=="Rotterdam" | city=="Utrecht" | city=="Den Haag" | city=="Nijmegen" | city=="Groningen" | city=="Heerlen" | city=="Eindhoven" | city=="Arnhem"
tabstat drugs1 drugs2  drugs3  violence1  violence2 violence3  , s(mean sd) f(%5.2f)



/****************************/
/*** Perceived 22 cities  ***/
/****************************/

use "C:\Users\skastoryano\Dropbox\Tippelzone G\TempTipp\Tippelzone2015\PMBperc2015.dta", clear 

drop if city=="Amsterdam"
drop if city=="Rotterdam"
drop if city=="Den Haag"
drop if city=="Eindhoven" & year==2011


gen openingO=0
replace openingO=1 if everopenONoReg==1
replace openingO=1 if openingORegA==1
gen openingTB=0
replace openingTB=1 if everopenTBNoReg==1
replace openingTB=1 if openingTBRegA==1


/*** Table 7 ***/
/***************/


fvset base 2001 year
local controls "male age educ dutch  logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorD66 mayorVVD"
local effects "openingO openingTB"
xtset postcijf  
eststo: qui areg drugs1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
eststo: qui areg drugOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf) 
eststo: qui areg violence1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
eststo: qui areg violOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
esttab, se b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear

fvset base 2001 year
local controls "male age educ dutch  logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorD66 mayorVVD"
local effects "everopenONoReg openingORegP openingORegA  everopenTBNoReg openingTBRegP openingTBRegA "
xtset postcijf  
eststo: qui areg drugs1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
eststo: qui areg drugOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf) 
eststo: qui areg violence1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
eststo: qui areg violOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
esttab, se b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Table 8 ***/
/***************/
local controls "male age educ dutch  logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorD66 mayorVVD"
xtset postcijf    
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg drugs1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg drugOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf) 
esttab, se b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear


/*** Appendix Table 15 ***/
/************************/
fvset base 2001 year
local controls "male age educ dutch  logpopmale1565 logpopdens inkhh educhpc nondutchpc insurWWAO mayorCDA mayorD66 mayorVVD"
xtset postcijf  
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg drugs1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg drugOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)   
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg violence1 `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf)  
local effects "openingO12m  openingONoReg12 everopenONoReg38p  openingORegP openingOReg12 openingOReg38pA  openingTB12m  openingTBNoReg12  everopenTBNoReg38p  openingTBRegP openingTBReg12 openingTBReg38pA  regspillNoReg closespillNoReg brothelban"
eststo: qui areg violOftSomU `effects' `controls' i.year, absorb(postcijf) vce(cluster postcijf) 
esttab, se b(3) ar2(a2) star(* 0.10 ** 0.05 *** 0.01 ) keep(`effects')
eststo clear




